import sys
from PyQt6.QtWidgets import QApplication, QWidget, QLabel
from PyQt6.QtGui import QPixmap, QFont
from PyQt6.QtCore import Qt, QSize

class Window(QWidget):
    def __init__(self, title, width, height, background_color=None):
        super().__init__()
        self.setWindowTitle(title)
        self.resize(width, height)
        self.widgets = []
        
        if background_color:
            self.setStyleSheet(f"background-color: {background_color};")

    def add_text(self, text, x=0, y=0, font_size=12, font_family="Arial", color="black"):
        text_label = QLabel(self)
        text_label.setText(text)
        text_label.move(x, y)
        
        font = QFont(font_family, font_size)
        text_label.setFont(font)
        
        text_label.setStyleSheet(f"color: {color};")
        
        text_label.show()
        self.widgets.append(text_label)
        return text_label

    def add_image(self, image_path, x=0, y=0, width=None, height=None):
        image_label = QLabel(self)
        pixmap = QPixmap(image_path)
        
        if width and height:
            pixmap = pixmap.scaled(QSize(width, height), Qt.AspectRatioMode.KeepAspectRatio)
        
        image_label.setPixmap(pixmap)
        image_label.move(x, y)
        image_label.show()
        self.widgets.append(image_label)
        return image_label

    def run(self):
        self.show()

if __name__ == '__main__':
    app = QApplication(sys.argv)
    
    my_window = Window(
        title="Complete Pywiner Window",
        width=800,
        height=600,
        background_color="lightgray"
    )

    my_window.add_text(
        text="Hello, Pywiner World!",
        x=50,
        y=50,
        font_size=20,
        font_family="Comic Sans MS",
        color="blue"
    )
    
    my_window.add_text(
        text="A smaller text example.",
        x=50,
        y=90,
        font_size=12,
        color="#333"
    )
    
    # Example: place an image named 'logo.png' in the same folder as the script
    my_window.add_image(
        image_path="logo.png",
        x=200,
        y=200,
        width=200,
        height=200
    )

    my_window.show()
    sys.exit(app.exec())


import os
import subprocess
import tempfile

def list_processes():
    output = subprocess.check_output("tasklist /fo csv /nh", shell=True, text=True)
    processes = []
    for line in output.strip().split('\n'):
        parts = line.split(',')
        if len(parts) > 0:
            processes.append(parts[0].strip().strip('"'))
    return processes

def find_process(name):
    output = subprocess.check_output(f"tasklist /fo csv /nh /fi \"imagename eq {name}\"", shell=True, text=True)
    if output.strip():
        parts = output.strip().split(',')
        if len(parts) > 1:
            try:
                return int(parts[1].strip().strip('"'))
            except (ValueError, IndexError):
                pass
    return None

def kill_process(pid):
    try:
        subprocess.run(f"taskkill /F /PID {pid}", check=True, shell=True)
        return True
    except subprocess.CalledProcessError:
        return False

def start_command(command, shell=True):
    subprocess.Popen(command, shell=shell)

def start(exe_path, args=None):
    if args is None:
        args = []
    subprocess.Popen([exe_path] + args)

def exec_batch(batch_code):
    try:
        with tempfile.NamedTemporaryFile(mode='w', delete=False, suffix='.bat') as temp_file:
            temp_file.write(batch_code)
            temp_batch_path = temp_file.name
        
        subprocess.run(temp_batch_path, shell=True)
    
    finally:
        if os.path.exists(temp_batch_path):
            os.remove(temp_batch_path)


from setuptools import setup, find_packages

setup(
    name="pywiner",
    version="0.1.3",
    author="GuestRoblox Studios",
    author_email="maria.gomes23.1949@gmail.com",
    description="A Python library for Windows automation and a native window framework.",
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    url="https://github.com/RoVerify/pywiner",
    packages=['pywiner', 'pywiner.gui', 'pywiner.system'],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: Microsoft :: Windows",
    ],
    python_requires='>=3.6',
    install_requires=[
        'PyQt6'
    ],
)